@@ -1,6 +1,6 @@
 # -*- Mode: perl -*-
 #
-# $Id: MxScreen.pm,v 0.1 2001/04/22 17:57:03 ram Exp $
+# $Id: MxScreen.pm,v 0.1.1.1 2001/05/30 21:13:07 ram Exp $
 #
 #  Copyright (c) 1998-2001, Raphael Manfredi
 #  Copyright (c) 2000-2001, Christophe Dehaudt
@@ -10,6 +10,11 @@
 #
 # HISTORY
 # $Log: MxScreen.pm,v $
+# Revision 0.1.1.1  2001/05/30 21:13:07  ram
+# patch1: fixed HISTORY section
+# patch1: random cleanup in named argument docs
+# patch1: updated version number
+#
 # Revision 0.1  2001/04/22 17:57:03  ram
 # Baseline for first Alpha release.
 #
@@ -22,7 +27,7 @@ use strict;
 package CGI::MxScreen;
 
 use vars qw($VERSION $BIN_VERSION);
-$VERSION = '0.1';
+$VERSION = '0.101';
 $BIN_VERSION = '0.1';
 
 use CGI::MxScreen::Constant;
@@ -2170,19 +2175,20 @@ named arguments, some of which are optional:
 
 =over 4
 
-=item C<-bgcolor> I<color>
+=item C<-bgcolor> => I<color>
 
-Optional, sets the background color to be used for all screens.  The
-default value is I<gray75>, aka C<"#bfbfbf">, which is the default background
-in Netscape on Unix.  The value you supply will be used in the BGCOLOR
-HTML tag, so any legal value there can be used.  For instance:
+Optional, sets the default background color to be used for all screens.
+If unspecified, the value is I<gray75>, aka C<"#bfbfbf">, which is the
+default background in Netscape on Unix.  The value you supply will be
+used in the BGCOLOR HTML tag, so any legal value there can be used.
+For instance:
 
     -bgcolor    => "beige"
 
 You may override the default background on a screen basis, as explained
-in L<CGI::MxScreen::Screen>.
+in L<CGI::MxScreen::Screen/"Creation Routine">.
 
-=item C<-initial> I<scalar> | I<array_ref>
+=item C<-initial> => I<scalar> | I<array_ref>
 
 Mandatory, defines the initial state.  See L<States> above for the
 actual format details.
@@ -2195,13 +2201,13 @@ The following two forms have identical effects:
 and both define a state I<Color> whose C<display()> routine is called
 without arguments.
 
-=item C<-layout> I<layout_object>
+=item C<-layout> => I<layout_object>
 
 Optional, provides a C<CGI::MxScreen::Layout> object to be used for laying
 out the screen's HTML generated by C<display()>.  See L<CGI::MxScreen::Layout>
 for details.
 
-=item C<-screens> I<hash_ref>
+=item C<-screens> => I<hash_ref>
 
 Mandatory, defines the list of valid states, whose class will handle it, and
 what the title of the page should be in that state.  Usually, there is
@@ -2212,7 +2218,9 @@ slightly different mode of operation.
 The hash reference given here is indexed by state names.  The values must
 be array references, and their content is the list of arguments to supply
 to the screen's creation routine, plus a C<-class> argument defining the
-class to use.
+class to use.  See L<CGI::MxScreen::Screen/"Creation Routine">.
+
+Example of I<hash_ref>:
 
     {
         'Color'     => [-class => 'Color',   -title => "Choose Color" ],
@@ -2221,7 +2229,7 @@ class to use.
 
 The above sequence defines two states, each implemented by its own class.
 
-=item C<-timeout> I<seconds>
+=item C<-timeout> => I<seconds>
 
 Optional, defines a session timeout, which will be enforced by C<CGI::MxScreen>
 when retrieving the session context.  It must be smaller than the session
@@ -2230,7 +2238,7 @@ cleaning timout, if sessions are not stored within the browser.
 When the session is expired, there is an error message stating so and the
 user is invited to restart a new session.
 
-=item C<-version> I<string>
+=item C<-version> => I<string>
 
 Defines the script's version.  This is I<your> versioning scheme, which has
 nothing to do with the one used by C<CGI::MxScreen>.
@@ -2427,8 +2435,10 @@ modularize the various concepts in late 1998 and early 1999.  It was
 never published, and was too procedural.
 
 In late 1999, I introduced my C<CGI::MxScreen> to Christophe Dehaudt.
-He had problems jumping into it, and once he was familiar with the
-underlying architecture, he proposed to redesign it from scratch.  I agreed.
+After studying it for a while, he bought the overall concept, but
+proposed to drop the procedural approach and switch to a pure object-oriented
+design, to make the framework easier to work with.  I agreed.
+
 
 The current version of C<CGI::MxScreen> is the result of a joint work
 between us.  Christophe did the initial experimenting with the new ideas,
