@@ -1,6 +1,6 @@
 # -*- Mode: perl -*-
 #
-# $Id: Exception.pm,v 0.1 2001/04/22 17:57:03 ram Exp $
+# $Id: Exception.pm,v 0.1.1.1 2001/05/30 21:13:28 ram Exp $
 #
 #  Copyright (c) 1998-2001, Raphael Manfredi
 #  Copyright (c) 2000-2001, Christophe Dehaudt
@@ -10,6 +10,9 @@
 #
 # HISTORY
 # $Log: Exception.pm,v $
+# Revision 0.1.1.1  2001/05/30 21:13:28  ram
+# patch1: removed DFEATURE call from stringify hook
+#
 # Revision 0.1  2001/04/22 17:57:03  ram
 # Baseline for first Alpha release.
 #
@@ -39,13 +42,11 @@ sub make {
 # For display purposes, if they try to stringify us.
 #
 sub stringify {
-	DFEATURE my $f_;
+	# Can't DFEATURE this routine, or would be a recursive call
 	my $self = shift;
-
 	my $pkg = ref $self;
 	$pkg =~ s/^__PACKAGE__:://;
-
-	return DVAL "CGI::MxScreen exception (type $pkg)";
+	return "CGI::MxScreen exception (type $pkg)";
 }
 
 1;
